@@ -10,7 +10,8 @@ from typing import Dict, List, Optional, Tuple, Union
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.search_space import SearchSpace
 from ax.core.types import TParamValue
-from ax.utils.common.equality import Base, equality_typechecker
+from ax.utils.common.base import Base
+from ax.utils.common.equality import equality_typechecker
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast
 from ax.utils.measurement.synthetic_functions import SyntheticFunction
