@@ -44,6 +44,7 @@ class TrialTest(TestCase):
         self.assertEqual(self.experiment, self.trial.experiment)
         self.assertEqual(self.trial.index, 0)
         self.assertEqual(self.trial.status, TrialStatus.CANDIDATE)
+        self.assertTrue(self.trial.status.is_candidate)
         self.assertIsNotNone(self.trial.time_created)
         self.assertEqual(self.trial.arms_by_name["0_0"], self.trial.arm)
         self.assertEqual(self.trial.arms, [self.arm])
@@ -65,14 +66,27 @@ class TrialTest(TestCase):
 
     def test_adding_new_trials(self):
         new_arm = get_arms()[1]
+        cand_metadata = {new_arm.signature: {"a": "b"}}
         new_trial = self.experiment.new_trial(
-            generator_run=GeneratorRun(arms=[new_arm])
+            generator_run=GeneratorRun(
+                arms=[new_arm], candidate_metadata_by_arm_signature=cand_metadata
+            )
         )
         with self.assertRaises(ValueError):
             self.experiment.new_trial(generator_run=GeneratorRun(arms=get_arms()))
         self.assertEqual(new_trial.arms_by_name["1_0"], new_arm)
         with self.assertRaises(KeyError):
             self.trial.arms_by_name["1_0"]
+        self.assertEqual(
+            new_trial._get_candidate_metadata_from_all_generator_runs(),
+            {"1_0": cand_metadata[new_arm.signature]},
+        )
+        self.assertEqual(
+            new_trial._get_candidate_metadata("1_0"), cand_metadata[new_arm.signature]
+        )
+        self.assertRaises(
+            ValueError, new_trial._get_candidate_metadata, "this_is_not_an_arm"
+        )
 
     def test_add_trial_same_arm(self):
         # Check that adding new arm w/out name works correctly.
@@ -101,6 +115,27 @@ class TrialTest(TestCase):
         self.assertFalse(self.trial.status.is_failed)
         self.assertTrue(self.trial.did_not_complete)
 
+    def test_mark_as(self):
+        for terminal_status in (
+            TrialStatus.ABANDONED,
+            TrialStatus.FAILED,
+            TrialStatus.COMPLETED,
+        ):
+            self.setUp()
+            # Note: This only tests the no-runner case (and thus not staging)
+            for status in (TrialStatus.RUNNING, terminal_status):
+                kwargs = {}
+                if status == TrialStatus.RUNNING:
+                    kwargs["no_runner_required"] = True
+                if status == TrialStatus.ABANDONED:
+                    kwargs["reason"] = "test_reason"
+                self.trial.mark_as(status=status, **kwargs)
+                self.assertTrue(self.trial.status == status)
+                if status == TrialStatus.ABANDONED:
+                    self.assertEqual(self.trial.abandoned_reason, "test_reason")
+                else:
+                    self.assertIsNone(self.trial.abandoned_reason)
+
     @patch(
         f"{BaseTrial.__module__}.{BaseTrial.__name__}.fetch_data",
         return_value=TEST_DATA,
@@ -122,3 +157,8 @@ class TrialTest(TestCase):
             "parameters={'w': 0.85, 'x': 1, 'y': 'baz', 'z': False}))"
         )
         self.assertEqual(str(self.trial), repr_)
+
+    def test_update_run_metadata(self):
+        self.assertEqual(len(self.trial.run_metadata), 0)
+        self.trial.update_run_metadata({"something": "new"})
+        self.assertEqual(self.trial.run_metadata, {"something": "new"})
