@@ -7,37 +7,27 @@
 from typing import Any, Callable, Dict, List, Optional, Set, Tuple
 
 import numpy as np
-import torch
 from ax.core.observation import ObservationData, ObservationFeatures
 from ax.core.optimization_config import (
-    MultiObjectiveOptimizationConfig,
     OptimizationConfig,
-    TRefPoint,
 )
 from ax.core.search_space import SearchSpace
 from ax.core.types import TCandidateMetadata, TConfig, TGenMetadata
 from ax.modelbridge.base import ModelBridge
 from ax.modelbridge.modelbridge_utils import (
-    extract_objective_thresholds,
+    array_to_observation_data,
     extract_objective_weights,
     extract_outcome_constraints,
     extract_parameter_constraints,
     get_bounds_and_task,
     get_fixed_features,
+    observation_data_to_array,
+    observation_features_to_array,
     parse_observation_features,
     pending_observations_as_array,
     transform_callback,
-    validate_and_apply_final_transform,
 )
-from ax.models.torch.frontier_utils import (
-    TFrontierEvaluator,
-    get_default_frontier_evaluator,
-    get_weighted_mc_objective_and_objective_thresholds,
-)
-from ax.utils.common.docutils import copy_doc
-from ax.utils.common.typeutils import checked_cast_optional, not_none
-from botorch.utils.multi_objective.hypervolume import Hypervolume
-from torch import Tensor
+from ax.utils.common.typeutils import not_none
 
 
 FIT_MODEL_ERROR = "Model must be fit before {action}."
@@ -128,6 +118,7 @@ class ArrayModelBridge(ModelBridge):
 
     def _update(
         self,
+        search_space: SearchSpace,
         observation_features: List[ObservationFeatures],
         observation_data: List[ObservationData],
     ) -> None:
@@ -138,12 +129,23 @@ class ArrayModelBridge(ModelBridge):
             outcomes=self.outcomes,
             parameters=self.parameters,
         )
+
+        bounds, task_features, target_fidelities = get_bounds_and_task(
+            search_space=search_space, param_names=self.parameters
+        )
+
         # Update in-design status for these new points.
         self._model_update(
             Xs=Xs_array,
             Ys=Ys_array,
             Yvars=Yvars_array,
             candidate_metadata=candidate_metadata,
+            bounds=bounds,
+            task_features=task_features,
+            feature_names=self.parameters,
+            metric_names=self.outcomes,
+            fidelity_features=list(target_fidelities.keys()),
+            target_fidelities=target_fidelities,
         )
 
     def _model_update(
@@ -151,10 +153,26 @@ class ArrayModelBridge(ModelBridge):
         Xs: List[np.ndarray],
         Ys: List[np.ndarray],
         Yvars: List[np.ndarray],
-        candidate_metadata: Optional[List[List[TCandidateMetadata]]] = None,
+        candidate_metadata: Optional[List[List[TCandidateMetadata]]],
+        bounds: List[Tuple[float, float]],
+        task_features: List[int],
+        feature_names: List[str],
+        metric_names: List[str],
+        fidelity_features: List[int],
+        target_fidelities: Optional[Dict[int, float]],
     ) -> None:
         self.model.update(
-            Xs=Xs, Ys=Ys, Yvars=Yvars, candidate_metadata=candidate_metadata
+            Xs=Xs,
+            Ys=Ys,
+            Yvars=Yvars,
+            candidate_metadata=candidate_metadata,
+            bounds=bounds,
+            task_features=task_features,
+            feature_names=self.parameters,
+            metric_names=self.outcomes,
+            fidelity_features=list(target_fidelities.keys())
+            if target_fidelities
+            else None,
         )
 
     def _predict(
@@ -201,9 +219,7 @@ class ArrayModelBridge(ModelBridge):
         bounds, _, target_fidelities = get_bounds_and_task(
             search_space=search_space, param_names=self.parameters
         )
-        target_fidelities = {
-            i: float(v) for i, v in target_fidelities.items()  # pyre-ignore [6]
-        }
+        target_fidelities = {i: float(v) for i, v in target_fidelities.items()}
 
         if optimization_config is None:
             raise ValueError(
@@ -325,6 +341,7 @@ class ArrayModelBridge(ModelBridge):
 
     def _cross_validate(
         self,
+        search_space: SearchSpace,
         obs_feats: List[ObservationFeatures],
         obs_data: List[ObservationData],
         cv_test_points: List[ObservationFeatures],
@@ -338,12 +355,24 @@ class ArrayModelBridge(ModelBridge):
             outcomes=self.outcomes,
             parameters=self.parameters,
         )
+        bounds, task_features, target_fidelities = get_bounds_and_task(
+            search_space=search_space, param_names=self.parameters
+        )
+
         X_test = np.array(
             [[obsf.parameters[p] for p in self.parameters] for obsf in cv_test_points]
         )
         # Use the model to do the cross validation
         f_test, cov_test = self._model_cross_validate(
-            Xs_train=Xs_train, Ys_train=Ys_train, Yvars_train=Yvars_train, X_test=X_test
+            Xs_train=Xs_train,
+            Ys_train=Ys_train,
+            Yvars_train=Yvars_train,
+            X_test=X_test,
+            bounds=bounds,
+            task_features=task_features,
+            feature_names=self.parameters,
+            metric_names=self.outcomes,
+            fidelity_features=list(target_fidelities.keys()),
         )
         # Convert array back to ObservationData
         return array_to_observation_data(f=f_test, cov=cov_test, outcomes=self.outcomes)
@@ -354,9 +383,22 @@ class ArrayModelBridge(ModelBridge):
         Ys_train: List[np.ndarray],
         Yvars_train: List[np.ndarray],
         X_test: np.ndarray,
+        bounds: List[Tuple[float, float]],
+        task_features: List[int],
+        feature_names: List[str],
+        metric_names: List[str],
+        fidelity_features: List[int],
     ) -> Tuple[np.ndarray, np.ndarray]:  # pragma: no cover
         return self.model.cross_validate(
-            Xs_train=Xs_train, Ys_train=Ys_train, Yvars_train=Yvars_train, X_test=X_test
+            Xs_train=Xs_train,
+            Ys_train=Ys_train,
+            Yvars_train=Yvars_train,
+            X_test=X_test,
+            bounds=bounds,
+            task_features=task_features,
+            feature_names=feature_names,
+            metric_names=metric_names,
+            fidelity_features=fidelity_features,
         )
 
     def _evaluate_acquisition_function(
@@ -436,264 +478,6 @@ class ArrayModelBridge(ModelBridge):
         except (KeyError, TypeError):  # pragma: no cover
             raise ValueError("Invalid formatting of observation features.")
 
-    @copy_doc(ModelBridge._pareto_frontier)
-    # pyre-fixme[14]: `_pareto_frontier` overrides method defined in `ModelBridge`
-    #  inconsistently.
-    def _pareto_frontier(
-        self,
-        objective_thresholds: Optional[TRefPoint] = None,
-        observation_features: Optional[List[ObservationFeatures]] = None,
-        observation_data: Optional[List[ObservationData]] = None,
-        optimization_config: Optional[MultiObjectiveOptimizationConfig] = None,
-    ) -> List[ObservationData]:
-        # TODO(jej): This method should be refactored to move tensor
-        # conversions into a separate utility, and eventually should be
-        # moved into base.py.
-        # The reason this method is currently implemented in array.py is to
-        # allow the broadest possible set of models to call frontier and
-        # hypervolume evaluation functions given the current API.
-        X = (
-            self.transform_observation_features(observation_features)
-            if observation_features
-            else None
-        )
-        X = self._array_to_tensor(X) if X is not None else None
-        Y, Yvar = (None, None)
-        if observation_data:
-            Y, Yvar = self.transform_observation_data(observation_data)
-        if Y is not None and Yvar is not None:
-            Y, Yvar = (self._array_to_tensor(Y), self._array_to_tensor(Yvar))
-
-        # Optimization_config
-        mooc = optimization_config or checked_cast_optional(
-            MultiObjectiveOptimizationConfig, self._optimization_config
-        )
-        if not mooc:
-            raise ValueError(
-                (
-                    "experiment must have an existing optimization_config "
-                    "of type MultiObjectiveOptimizationConfig "
-                    "or `optimization_config` must be passed as an argument."
-                )
-            )
-        if not isinstance(mooc, MultiObjectiveOptimizationConfig):
-            mooc = not_none(MultiObjectiveOptimizationConfig.from_opt_conf(mooc))
-        if objective_thresholds:
-            mooc = mooc.clone_with_args(objective_thresholds=objective_thresholds)
-
-        optimization_config = mooc
-
-        # Transform OptimizationConfig.
-        optimization_config = self.transform_optimization_config(
-            optimization_config=optimization_config,
-            fixed_features=ObservationFeatures(parameters={}),
-        )
-        # Extract weights, constraints, and objective_thresholds
-        objective_weights = extract_objective_weights(
-            objective=optimization_config.objective, outcomes=self.outcomes
-        )
-        outcome_constraints = extract_outcome_constraints(
-            outcome_constraints=optimization_config.outcome_constraints,
-            outcomes=self.outcomes,
-        )
-        objective_thresholds_arr = extract_objective_thresholds(
-            objective_thresholds=optimization_config.objective_thresholds,
-            outcomes=self.outcomes,
-        )
-        # Transform to tensors.
-        obj_w, oc_c, _, _ = validate_and_apply_final_transform(
-            objective_weights=objective_weights,
-            outcome_constraints=outcome_constraints,
-            linear_constraints=None,
-            pending_observations=None,
-            final_transform=self._array_to_tensor,
-        )
-        obj_t = self._array_to_tensor(objective_thresholds_arr)
-        frontier_evaluator = self._get_frontier_evaluator()
-        # pyre-ignore[28]: Unexpected keyword `model` to anonymous call
-        f, cov = frontier_evaluator(
-            model=self.model,
-            X=X,
-            Y=Y,
-            Yvar=Yvar,
-            objective_thresholds=obj_t,
-            objective_weights=obj_w,
-            outcome_constraints=oc_c,
-        )
-        f, cov = f.detach().cpu().clone().numpy(), cov.detach().cpu().clone().numpy()
-        frontier_observation_data = array_to_observation_data(
-            f=f, cov=cov, outcomes=not_none(self.outcomes)
-        )
-        # Untransform observations
-        for t in reversed(self.transforms.values()):  # noqa T484
-            frontier_observation_data = t.untransform_observation_data(
-                frontier_observation_data, []
-            )
-        return frontier_observation_data
-
-    @copy_doc(ModelBridge.predicted_pareto_frontier)
-    def predicted_pareto_frontier(
-        self,
-        objective_thresholds: Optional[TRefPoint] = None,
-        observation_features: Optional[List[ObservationFeatures]] = None,
-        optimization_config: Optional[OptimizationConfig] = None,
-    ) -> List[ObservationData]:
-        # If observation_features is not provided, use model training features.
-        observation_features = (
-            observation_features
-            if observation_features is not None
-            else [obs.features for obs in self.get_training_data()]
-        )
-        if not observation_features:
-            raise ValueError(
-                "Must receive observation_features as input or the model must "
-                "have training data."
-            )
-
-        return self._pareto_frontier(
-            objective_thresholds=objective_thresholds,
-            observation_features=observation_features,
-            # pyre-fixme[6]: Expected `Optional[MultiObjectiveOptimizationConfig]`
-            #  for 3rd param but got `Optional[OptimizationConfig]`.
-            optimization_config=optimization_config,
-        )
-
-    @copy_doc(ModelBridge._hypervolume)
-    def _hypervolume(
-        self,
-        objective_thresholds: Optional[TRefPoint] = None,
-        observation_features: Optional[List[ObservationFeatures]] = None,
-        observation_data: Optional[List[ObservationData]] = None,
-        optimization_config: Optional[OptimizationConfig] = None,
-    ) -> float:
-        # Extract a tensor of outcome means from observation data.
-        observation_data = self._pareto_frontier(
-            objective_thresholds=objective_thresholds,
-            observation_features=observation_features,
-            observation_data=observation_data,
-            # pyre-fixme[6]: Expected `Optional[MultiObjectiveOptimizationConfig]`
-            #  for 4th param but got `Optional[OptimizationConfig]`.
-            optimization_config=optimization_config,
-        )
-        if not observation_data:
-            # The hypervolume of an empty set is always 0.
-            return 0
-        means, _ = self._transform_observation_data(observation_data)
-
-        # Extract objective_weights and objective_thresholds
-        if optimization_config is None:
-            optimization_config = (
-                # pyre-fixme[16]: `Optional` has no attribute `clone`.
-                self._optimization_config.clone()
-                if self._optimization_config is not None
-                else None
-            )
-        else:
-            optimization_config = optimization_config.clone()
-
-        if objective_thresholds is not None:
-            optimization_config = optimization_config.clone_with_args(
-                objective_thresholds=objective_thresholds
-            )
-
-        obj_w = extract_objective_weights(
-            objective=optimization_config.objective, outcomes=self.outcomes
-        )
-        obj_w = self._array_to_tensor(obj_w)  # TODO: can I get rid of these tensors?
-        objective_thresholds_arr = extract_objective_thresholds(
-            objective_thresholds=optimization_config.objective_thresholds,
-            outcomes=self.outcomes,
-        )
-        obj_t = self._array_to_tensor(
-            objective_thresholds_arr
-        )  # TODO: can I get rid of these tensors?
-        obj, obj_t = get_weighted_mc_objective_and_objective_thresholds(
-            objective_weights=obj_w, objective_thresholds=obj_t
-        )
-        means = obj(means)
-        hv = Hypervolume(ref_point=obj_t)
-        return hv.compute(means)
-
-    @copy_doc(ModelBridge.predicted_hypervolume)
-    def predicted_hypervolume(
-        self,
-        objective_thresholds: Optional[TRefPoint] = None,
-        observation_features: Optional[List[ObservationFeatures]] = None,
-        optimization_config: Optional[OptimizationConfig] = None,
-    ) -> float:
-        # If observation_features is not provided, use model training features.
-        observation_features = (
-            observation_features
-            if observation_features is not None
-            else [obs.features for obs in self.get_training_data()]
-        )
-        if not observation_features:
-            raise ValueError(
-                "Must receive observation_features as input or the model must "
-                "have training data."
-            )
-
-        return self._hypervolume(
-            objective_thresholds=objective_thresholds,
-            observation_features=observation_features,
-            optimization_config=optimization_config,
-        )
-
-    def _get_frontier_evaluator(self) -> TFrontierEvaluator:
-        return get_default_frontier_evaluator()
-
-    def _array_to_tensor(self, array: np.ndarray) -> Tensor:
-        return torch.tensor(array)
-
-
-def array_to_observation_data(
-    f: np.ndarray, cov: np.ndarray, outcomes: List[str]
-) -> List[ObservationData]:
-    """Convert arrays of model predictions to a list of ObservationData.
-
-    Args:
-        f: An (n x m) array
-        cov: An (n x m x m) array
-        outcomes: A list of d outcome names
-
-    Returns: A list of n ObservationData
-    """
-    observation_data = []
-    for i in range(f.shape[0]):
-        observation_data.append(
-            ObservationData(
-                metric_names=list(outcomes),
-                means=f[i, :].copy(),
-                covariance=cov[i, :, :].copy(),
-            )
-        )
-    return observation_data
-
-
-def observation_data_to_array(
-    observation_data: List[ObservationData],
-) -> Tuple[np.ndarray, np.ndarray]:
-    """Convert a list of Observation data to arrays.
-
-    Args:
-        observation_data: A list of n ObservationData
-
-    Returns:
-        An array of n ObservationData, each containing
-            - f: An (n x m) array
-            - cov: An (n x m x m) array
-    """
-    means = np.array([obsd.means for obsd in observation_data])
-    covs = np.array([obsd.covariance for obsd in observation_data])
-    return means, covs
-
-
-def observation_features_to_array(
-    parameters: List[str], obsf: List[ObservationFeatures]
-) -> np.ndarray:
-    """Convert a list of Observation features to arrays."""
-    return np.array([[of.parameters[p] for p in parameters] for of in obsf])
-
 
 def _convert_observations(
     observation_data: List[ObservationData],
