@@ -487,3 +487,76 @@ def get_MOO_RS(
             },
         ),
     )
+
+
+def get_MTGP_PAREGO(
+    experiment: Experiment,
+    data: Data,
+    trial_index: Optional[int] = None,
+    objective_thresholds: Optional[TRefPoint] = None,
+    search_space: Optional[SearchSpace] = None,
+    dtype: torch.dtype = torch.double,
+    device: torch.device = DEFAULT_TORCH_DEVICE,
+) -> MultiObjectiveTorchModelBridge:
+    """Instantiates a multi-objective, multi-task model that uses qParEGO.
+
+    qParEGO optimizes random augmented chebyshev scalarizations of the multiple
+    objectives. This allows it to explore non-convex pareto frontiers.
+    """
+    # pyre-ignore: [16] `Optional` has no attribute `objective`.
+    if not isinstance(experiment.optimization_config.objective, MultiObjective):
+        raise ValueError("Multi-objective optimization requires multiple objectives.")
+    elif data.df.empty:  # pragma: no cover
+        raise ValueError("MultiObjectiveOptimization requires non-empty data.")
+
+    if isinstance(experiment, MultiTypeExperiment):
+        trial_index_to_type = {
+            t.index: t.trial_type for t in experiment.trials.values()
+        }
+        transforms = MT_MTGP_trans
+        transform_configs = {
+            "ConvertMetricNames": tconfig_from_mt_experiment(experiment),
+            "TrialAsTask": {"trial_level_map": {"trial_type": trial_index_to_type}},
+        }
+    else:
+        # Set transforms for a Single-type MTGP model.
+        transforms = ST_MTGP_trans
+        transform_configs = None
+
+    # Choose the status quo features for the experiment from the selected trial.
+    # If trial_index is None, we will look for a status quo from the last
+    # experiment trial to use as a status quo for the experiment.
+    if trial_index is None:
+        trial_index = len(experiment.trials) - 1
+    elif trial_index >= len(experiment.trials):
+        raise ValueError("trial_index is bigger than the number of experiment trials")
+
+    # pyre-fixme[16]: `ax.core.base_trial.BaseTrial` has no attribute `status_quo`.
+    status_quo = experiment.trials[trial_index].status_quo
+    if status_quo is None:
+        status_quo_features = None
+    else:
+        status_quo_features = ObservationFeatures(
+            parameters=status_quo.parameters, trial_index=trial_index
+        )
+    return checked_cast(
+        MultiObjectiveTorchModelBridge,
+        Models.MOO(
+            experiment=experiment,
+            data=data,
+            objective_thresholds=objective_thresholds,
+            search_space=search_space or experiment.search_space,
+            torch_dtype=dtype,
+            torch_device=device,
+            acqf_constructor=get_NEI,
+            status_quo_features=status_quo_features,
+            transforms=transforms,
+            transform_configs=transform_configs,
+            default_model_gen_options={
+                "acquisition_function_kwargs": {
+                    "chebyshev_scalarization": True,
+                    "sequential": True,
+                }
+            },
+        ),
+    )
