@@ -11,8 +11,6 @@ from ax.models.torch.utils import (
     _generate_sobol_points,
     is_noiseless,
     normalize_indices,
-    sample_hypersphere_positive_quadrant,
-    sample_simplex,
     subset_model,
     tensor_callable_to_array_callable,
 )
@@ -49,47 +47,65 @@ class TorchUtilsTest(TestCase):
 
     def testSubsetModel(self):
         x = torch.zeros(1, 1)
-        y = torch.zeros(1, 2)
+        y = torch.rand(1, 2)
+        Ys = [y[:, :1], y[:, 1:]]
         model = SingleTaskGP(x, y)
         self.assertEqual(model.num_outputs, 2)
         # basic test, can subset
         obj_weights = torch.tensor([1.0, 0.0])
-        model_sub, obj_weights_sub, ocs_sub = subset_model(model, obj_weights)
+        model_sub, obj_weights_sub, ocs_sub, Ys_sub = subset_model(
+            model, obj_weights, Ys=Ys
+        )
         self.assertIsNone(ocs_sub)
         self.assertEqual(model_sub.num_outputs, 1)
         self.assertTrue(torch.equal(obj_weights_sub, torch.tensor([1.0])))
+        self.assertEqual(Ys_sub[0], Ys[0])
+        self.assertEqual(len(Ys_sub), 1)
         # basic test, cannot subset
         obj_weights = torch.tensor([1.0, 2.0])
-        model_sub, obj_weights_sub, ocs_sub = subset_model(model, obj_weights)
+        model_sub, obj_weights_sub, ocs_sub, Ys_sub = subset_model(
+            model, obj_weights, Ys=Ys
+        )
         self.assertIsNone(ocs_sub)
         self.assertIs(model_sub, model)  # check identity
         self.assertIs(obj_weights_sub, obj_weights)  # check identity
+        self.assertIs(Ys_sub, Ys)
         # test w/ outcome constraints, can subset
         obj_weights = torch.tensor([1.0, 0.0])
         ocs = (torch.tensor([[1.0, 0.0]]), torch.tensor([1.0]))
-        model_sub, obj_weights_sub, ocs_sub = subset_model(model, obj_weights, ocs)
+        model_sub, obj_weights_sub, ocs_sub, Ys_sub = subset_model(
+            model, obj_weights, ocs, Ys
+        )
         self.assertEqual(model_sub.num_outputs, 1)
         self.assertTrue(torch.equal(obj_weights_sub, torch.tensor([1.0])))
         self.assertTrue(torch.equal(ocs_sub[0], torch.tensor([[1.0]])))
         self.assertTrue(torch.equal(ocs_sub[1], torch.tensor([1.0])))
+        self.assertIs(Ys_sub[0], Ys[0])
+        self.assertEqual(len(Ys_sub), 1)
         # test w/ outcome constraints, cannot subset
         obj_weights = torch.tensor([1.0, 0.0])
         ocs = (torch.tensor([[0.0, 1.0]]), torch.tensor([1.0]))
-        model_sub, obj_weights_sub, ocs_sub = subset_model(model, obj_weights, ocs)
+        model_sub, obj_weights_sub, ocs_sub, Ys_sub = subset_model(
+            model, obj_weights, ocs, Ys
+        )
         self.assertIs(model_sub, model)  # check identity
         self.assertIs(obj_weights_sub, obj_weights)  # check identity
         self.assertIs(ocs_sub, ocs)  # check identity
+        self.assertIs(Ys_sub, Ys)
         # test unsupported
         yvar = torch.ones(1, 2)
         model = HeteroskedasticSingleTaskGP(x, y, yvar)
-        model_sub, obj_weights_sub, ocs = subset_model(model, obj_weights)
+        model_sub, obj_weights_sub, ocs, Ys_sub = subset_model(
+            model, obj_weights, Ys=Ys
+        )
         self.assertIsNone(ocs)
         self.assertIs(model_sub, model)  # check identity
         self.assertIs(obj_weights_sub, obj_weights)  # check identity
+        self.assertIs(Ys_sub, Ys)
         # test error on size inconsistency
         obj_weights = torch.ones(3)
         with self.assertRaises(RuntimeError):
-            subset_model(model, obj_weights)
+            subset_model(model, obj_weights, Ys=Ys)
 
     def testGenerateSobolPoints(self):
         bounds = [(0.0, 1.0) for _ in range(3)]
@@ -111,24 +127,6 @@ class TorchUtilsTest(TestCase):
         self.assertEqual(len(gen_sobol), 100)
         self.assertIsInstance(gen_sobol, Tensor)
 
-    def testSampleSimplex(self):
-        for d in range(1, 10):
-            self.assertTrue(
-                sample_simplex(d)
-                .sum()
-                .isclose(torch.tensor([1.0], dtype=torch.double)),
-                "sampled simplex point's components do not sum to 1.0",
-            )
-
-    def testSampleHyperspherePositiveQuadrant(self):
-        for d in range(1, 10):
-            self.assertTrue(
-                sample_hypersphere_positive_quadrant(d)
-                .norm()
-                .isclose(torch.tensor([1.0], dtype=torch.double)),
-                "sampled hypersphere point's norm is not 1.0",
-            )
-
     def testTensorCallableToArrayCallable(self):
         def tensor_func(x: Tensor) -> Tensor:
             return np.exp(x)
