@@ -85,6 +85,7 @@ class ALEBOKernel(Kernel):
         last_dim_is_batch: bool = False,
         **params: Any,
     ) -> Tensor:
+        """Compute kernel distance."""
         # Unpack Uvec into an upper triangular matrix U
         shapeU = self.Uvec.shape[:-1] + torch.Size([self.d, self.d])
         U_t = torch.zeros(shapeU, dtype=self.B.dtype, device=self.B.device)
@@ -655,7 +656,7 @@ class ALEBO(BotorchModel):
                 "B": self.B,
             },
         }
-        Xd_opt, w, _gen_metadata, _candidate_metadata = super().gen(
+        Xd_opt, w, gen_metadata, candidate_metadata = super().gen(
             n=n,
             bounds=[(-1e8, 1e8)] * self.B.shape[0],
             objective_weights=objective_weights,
@@ -673,7 +674,7 @@ class ALEBO(BotorchModel):
         # pyre-fixme[7]: Expected `Tuple[Tensor, Tensor, Dict[str, typing.Any],
         #  List[Optional[Dict[str, typing.Any]]]]` but got `Tuple[typing.Any, Tensor,
         #  Dict[str, typing.Any], None]`.
-        return Xopt, w, {}, None
+        return Xopt, w, gen_metadata, candidate_metadata
 
     @copy_doc(TorchModel.update)
     def update(
@@ -682,6 +683,7 @@ class ALEBO(BotorchModel):
         Ys: List[Tensor],
         Yvars: List[Tensor],
         candidate_metadata: Optional[List[List[TCandidateMetadata]]] = None,
+        **kwargs: Any,
     ) -> None:
         if self.model is None:
             raise RuntimeError(
@@ -707,6 +709,7 @@ class ALEBO(BotorchModel):
         Ys_train: List[Tensor],
         Yvars_train: List[Tensor],
         X_test: Tensor,
+        **kwargs: Any,
     ) -> Tuple[Tensor, Tensor]:
         if self.model is None:
             raise RuntimeError(
