@@ -7,7 +7,7 @@
 from __future__ import annotations
 
 from copy import deepcopy
-from typing import Any, Callable, Dict, List, Optional, Tuple, cast
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import numpy as np
 import torch
@@ -32,6 +32,7 @@ from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast
 from botorch.acquisition.acquisition import AcquisitionFunction
 from botorch.models.model import Model
+from botorch.models.model_list_gp_regression import ModelListGP
 from torch import Tensor
 
 
@@ -242,6 +243,7 @@ class BotorchModel(TorchModel):
         refit_on_update: bool = True,
         warm_start_refitting: bool = True,
         use_input_warping: bool = False,
+        use_loocv_pseudo_likelihood: bool = False,
         **kwargs: Any,
     ) -> None:
         self.model_constructor = model_constructor
@@ -254,6 +256,7 @@ class BotorchModel(TorchModel):
         self.refit_on_update = refit_on_update
         self.warm_start_refitting = warm_start_refitting
         self.use_input_warping = use_input_warping
+        self.use_loocv_pseudo_likelihood = use_loocv_pseudo_likelihood
         self.model: Optional[Model] = None
         self.Xs = []
         self.Ys = []
@@ -294,6 +297,7 @@ class BotorchModel(TorchModel):
             fidelity_features=self.fidelity_features,
             metric_names=self.metric_names,
             use_input_warping=self.use_input_warping,
+            use_loocv_pseudo_likelihood=self.use_loocv_pseudo_likelihood,
             **self._kwargs,
         )
 
@@ -424,12 +428,13 @@ class BotorchModel(TorchModel):
         )
 
     @copy_doc(TorchModel.cross_validate)
-    def cross_validate(
-        self,
+    def cross_validate(  # pyre-ignore[14]: Some `TorchModel.cross_validate` kwargs
+        self,  # are not needed here and therefore we just use `**kwargs` catchall.
         Xs_train: List[Tensor],
         Ys_train: List[Tensor],
         Yvars_train: List[Tensor],
         X_test: Tensor,
+        **kwargs: Any,
     ) -> Tuple[Tensor, Tensor]:
         if self.model is None:
             raise RuntimeError("Cannot cross-validate model that has not been fitted")
@@ -447,17 +452,19 @@ class BotorchModel(TorchModel):
             metric_names=self.metric_names,
             refit_model=self.refit_on_cv,
             use_input_warping=self.use_input_warping,
+            use_loocv_pseudo_likelihood=self.use_loocv_pseudo_likelihood,
             **self._kwargs,
         )
         return self.model_predictor(model=model, X=X_test)  # pyre-ignore: [28]
 
     @copy_doc(TorchModel.update)
-    def update(
-        self,
+    def update(  # pyre-ignore[14]: Some `TorchModel.update` kwargs are not
+        self,  # needed here and therefore we just use `**kwargs` catchall.
         Xs: List[Tensor],
         Ys: List[Tensor],
         Yvars: List[Tensor],
         candidate_metadata: Optional[List[List[TCandidateMetadata]]] = None,
+        **kwargs: Any,
     ) -> None:
         if self.model is None:
             raise RuntimeError("Cannot update model that has not been fitted")
@@ -478,6 +485,7 @@ class BotorchModel(TorchModel):
             metric_names=self.metric_names,
             refit_model=self.refit_on_update,
             use_input_warping=self.use_input_warping,
+            use_loocv_pseudo_likelihood=self.use_loocv_pseudo_likelihood,
             **self._kwargs,
         )
 
@@ -486,9 +494,18 @@ class BotorchModel(TorchModel):
             raise RuntimeError(
                 "Cannot calculate feature_importances without a fitted model"
             )
+        elif isinstance(self.model, ModelListGP):
+            models = self.model.models  # pyre-ignore: [16]
         else:
-            ls = self.model.covar_module.base_kernel.lengthscale  # pyre-ignore: [16]
-            return cast(Tensor, (1 / ls)).detach().cpu().numpy()
+            models = [self.model]
+        lengthscales = []
+        for m in models:
+            ls = m.covar_module.base_kernel.lengthscale
+            if ls.ndim == 2:
+                ls = ls.unsqueeze(0)
+            lengthscales.append(ls)
+        lengthscales = torch.cat(lengthscales, dim=0)
+        return (1 / lengthscales).detach().cpu().numpy()
 
 
 def get_rounding_func(
