@@ -34,9 +34,10 @@ from botorch.utils import (
 )
 from botorch.utils.multi_objective.scalarization import get_chebyshev_scalarization
 from gpytorch.mlls.exact_marginal_log_likelihood import ExactMarginalLogLikelihood
+from gpytorch.mlls.leave_one_out_pseudo_likelihood import LeaveOneOutPseudoLikelihood
 from gpytorch.mlls.sum_marginal_log_likelihood import SumMarginalLogLikelihood
 from gpytorch.priors.lkj_prior import LKJCovariancePrior
-from gpytorch.priors.torch_priors import GammaPrior
+from gpytorch.priors.torch_priors import GammaPrior, LogNormalPrior
 from torch import Tensor
 
 
@@ -53,6 +54,7 @@ def get_and_fit_model(
     state_dict: Optional[Dict[str, Tensor]] = None,
     refit_model: bool = True,
     use_input_warping: bool = False,
+    use_loocv_pseudo_likelihood: bool = False,
     **kwargs: Any,
 ) -> GPyTorchModel:
     r"""Instantiates and fits a botorch GPyTorchModel using the given data.
@@ -165,11 +167,15 @@ def get_and_fit_model(
     if state_dict is None or refit_model:
         # TODO: Add bounds for optimization stability - requires revamp upstream
         bounds = {}
+        if use_loocv_pseudo_likelihood:
+            mll_cls = LeaveOneOutPseudoLikelihood
+        else:
+            mll_cls = ExactMarginalLogLikelihood
         if isinstance(model, ModelListGP):
-            mll = SumMarginalLogLikelihood(model.likelihood, model)
+            mll = SumMarginalLogLikelihood(model.likelihood, model, mll_cls=mll_cls)
         else:
             # pyre-ignore: [16]
-            mll = ExactMarginalLogLikelihood(model.likelihood, model)
+            mll = mll_cls(model.likelihood, model)
         mll = fit_gpytorch_model(mll, bounds=bounds)
     return model
 
@@ -217,13 +223,17 @@ def get_NEI(
         obj_tf = get_chebyshev_scalarization(weights=objective_weights, Y=Y_tensor)
     else:
         obj_tf = get_objective_weights_transform(objective_weights)
+
+    def objective(samples: Tensor, X: Optional[Tensor] = None) -> Tensor:
+        return obj_tf(samples)
+
     if outcome_constraints is None:
-        objective = GenericMCObjective(objective=obj_tf)
+        objective = GenericMCObjective(objective=objective)
     else:
         con_tfs = get_outcome_constraint_transforms(outcome_constraints)
-        inf_cost = get_infeasible_cost(X=X_observed, model=model, objective=obj_tf)
+        inf_cost = get_infeasible_cost(X=X_observed, model=model, objective=objective)
         objective = ConstrainedMCObjective(
-            objective=obj_tf, constraints=con_tfs or [], infeasible_cost=inf_cost
+            objective=objective, constraints=con_tfs or [], infeasible_cost=inf_cost
         )
     return get_acquisition_function(
         acquisition_function_name="qNEI",
@@ -584,8 +594,8 @@ def get_warping_transform(
     # Note: this currently uses the same warping functions for all tasks
     tf = Warp(
         indices=indices,
-        # use an uninformative prior with maximum log probability at 1
-        concentration1_prior=GammaPrior(1.01, 0.01),
-        concentration0_prior=GammaPrior(1.01, 0.01),
+        # prior with a median of 1
+        concentration1_prior=LogNormalPrior(0.0, 0.75 ** 0.5),
+        concentration0_prior=LogNormalPrior(0.0, 0.75 ** 0.5),
     )
     return tf
