@@ -271,7 +271,7 @@ def _to_inequality_constraints(
         inequality_constraints = []
         k, d = A.shape
         for i in range(k):
-            indicies = A[i, :].nonzero().squeeze()
+            indicies = A[i, :].nonzero(as_tuple=False).squeeze()
             coefficients = -A[i, indicies]
             rhs = -b[i, 0]
             inequality_constraints.append((indicies, coefficients, rhs))
@@ -331,10 +331,14 @@ def get_botorch_objective(
                 "= True. Creating ConstrainedMCObjective."
             )
         obj_tf = get_objective_weights_transform(objective_weights)
+
+        def objective(samples: Tensor, X: Optional[Tensor] = None) -> Tensor:
+            return obj_tf(samples)
+
         con_tfs = get_outcome_constraint_transforms(outcome_constraints)
         inf_cost = get_infeasible_cost(X=X_observed, model=model, objective=obj_tf)
         return ConstrainedMCObjective(
-            objective=obj_tf, constraints=con_tfs or [], infeasible_cost=inf_cost
+            objective=objective, constraints=con_tfs or [], infeasible_cost=inf_cost
         )
     elif use_scalarized_objective:
         return ScalarizedObjective(weights=objective_weights)
