@@ -62,6 +62,7 @@ from ax.utils.testing.core_stubs import (
     get_mll_type,
     get_model_type,
     get_multi_objective,
+    get_multi_objective_optimization_config,
     get_multi_type_experiment,
     get_objective,
     get_objective_threshold,
@@ -108,6 +109,7 @@ TEST_CASES = [
     ("ListSurrogate", get_list_surrogate),
     ("Metric", get_metric),
     ("MultiObjective", get_multi_objective),
+    ("MultiObjectiveOptimizationConfig", get_multi_objective_optimization_config),
     ("MultiTypeExperiment", get_multi_type_experiment),
     ("ObservationFeatures", get_observation_features),
     ("Objective", get_objective),
