@@ -4,19 +4,42 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import List, Optional
+from typing import List, Optional, Tuple
 
 from ax.core.base_trial import BaseTrial
 from ax.core.experiment import Experiment
 from ax.core.generator_run import GeneratorRun
 from ax.core.trial import Trial
 from ax.modelbridge.generation_strategy import GenerationStrategy
-from ax.storage.sqa_store.db import optional_session_scope, session_scope
+from ax.storage.sqa_store.db import SQABase, optional_session_scope, session_scope
 from ax.storage.sqa_store.encoder import Encoder
 from ax.storage.sqa_store.sqa_config import SQAConfig
+from ax.utils.common.base import Base
+from ax.utils.common.logger import get_logger
+from ax.utils.common.typeutils import not_none
 from sqlalchemy.orm import Session
 
 
+logger = get_logger(__name__)
+
+
+def _set_db_ids(obj_to_sqa: List[Tuple[Base, SQABase]]) -> None:
+    for obj, sqa_obj in obj_to_sqa:
+        if sqa_obj.id is not None:  # pyre-ignore[16]
+            obj.db_id = not_none(sqa_obj.id)
+        elif obj.db_id is None:
+            is_sq_gr = (
+                isinstance(obj, GeneratorRun)
+                and obj._generator_run_type == "STATUS_QUO"
+            )
+            # TODO: Remove this warning when storage & perf project is complete.
+            if not is_sq_gr:
+                logger.warning(
+                    f"User-facing object {obj} does not already have a db_id, "
+                    f"and the corresponding SQA object: {sqa_obj} does not either."
+                )
+
+
 def save_experiment(experiment: Experiment, config: Optional[SQAConfig] = None) -> None:
     """Save experiment (using default SQAConfig)."""
     if not isinstance(experiment, Experiment):
@@ -53,7 +76,7 @@ def _save_experiment(experiment: Experiment, encoder: Encoder) -> None:
         #  got `Optional[ax.storage.sqa_store.db.SQABase]`.
         existing_sqa_experiment=existing_sqa_experiment,
     )
-    new_sqa_experiment = encoder.experiment_to_sqa(experiment)
+    new_sqa_experiment, obj_to_sqa = encoder.experiment_to_sqa(experiment)
 
     if existing_sqa_experiment is not None:
         # Update the SQA object outside of session scope to avoid timeouts.
@@ -66,6 +89,9 @@ def _save_experiment(experiment: Experiment, encoder: Encoder) -> None:
 
     with session_scope() as session:
         session.add(new_sqa_experiment)
+        session.flush()
+
+    _set_db_ids(obj_to_sqa=obj_to_sqa)
 
 
 def save_generation_strategy(
@@ -104,7 +130,7 @@ def _save_generation_strategy(
             encoder=encoder,
         )
 
-    gs_sqa = encoder.generation_strategy_to_sqa(
+    gs_sqa, obj_to_sqa = encoder.generation_strategy_to_sqa(
         generation_strategy=generation_strategy, experiment_id=experiment_id
     )
 
@@ -129,10 +155,9 @@ def _save_generation_strategy(
         session.add(gs_sqa)
         session.flush()  # Ensures generation strategy id is set.
 
-    # pyre-fixme[16]: `None` has no attribute `id`.
-    generation_strategy._db_id = gs_sqa.id
-    # pyre-fixme[7]: Expected `int` but got `Optional[int]`.
-    return generation_strategy._db_id
+    _set_db_ids(obj_to_sqa=obj_to_sqa)
+
+    return not_none(generation_strategy.db_id)
 
 
 def _get_experiment_id(
@@ -170,6 +195,7 @@ def _save_new_trials(
 ) -> None:
     """Add new trials to the experiment."""
     trial_sqa_class = encoder.config.class_to_sqa_class[Trial]
+    obj_to_sqa = []
     with session_scope() as session:
         experiment_id = _get_experiment_id(
             experiment=experiment, encoder=encoder, session=session
@@ -179,16 +205,29 @@ def _save_new_trials(
             .filter_by(experiment_id=experiment_id)
             .all()
         )
-        existing_trial_indices = {x[0] for x in existing_trial_indices}
 
-        for trial in trials:
-            if trial.index in existing_trial_indices:
-                raise ValueError(f"Trial {trial.index} already attached to experiment.")
+    existing_trial_indices = {x[0] for x in existing_trial_indices}
+    new_trial_idcs = set()
 
-            new_sqa_trial = encoder.trial_to_sqa(trial)
-            new_sqa_trial.experiment_id = experiment_id
-            session.add(new_sqa_trial)
-            existing_trial_indices.add(trial.index)
+    trials_sqa = []
+    for trial in trials:
+        if trial.index in existing_trial_indices:
+            raise ValueError(f"Trial {trial.index} already attached to experiment.")
+
+        if trial.index in new_trial_idcs:
+            raise ValueError(f"Trial {trial.index} appears in `trials` more than once.")
+
+        new_sqa_trial, _obj_to_sqa = encoder.trial_to_sqa(trial)
+        obj_to_sqa.extend(_obj_to_sqa)
+        new_sqa_trial.experiment_id = experiment_id
+        trials_sqa.append(new_sqa_trial)
+        new_trial_idcs.add(trial.index)
+
+    with session_scope() as session:
+        session.add_all(trials_sqa)
+        session.flush()
+
+    _set_db_ids(obj_to_sqa=obj_to_sqa)
 
 
 def update_trial(
@@ -211,6 +250,7 @@ def _update_trials(
     """Update trials and attach data."""
     trial_sqa_class = encoder.config.class_to_sqa_class[Trial]
     trial_indices = [trial.index for trial in trials]
+    obj_to_sqa = []
     with session_scope() as session:
         experiment_id = _get_experiment_id(
             experiment=experiment, encoder=encoder, session=session
@@ -221,28 +261,35 @@ def _update_trials(
             .filter(trial_sqa_class.index.in_(trial_indices))  # pyre-ignore
             .all()
         )
-        trial_index_to_existing_trial = {
-            trial.index: trial for trial in existing_trials
-        }
 
-        for trial in trials:
-            existing_trial = trial_index_to_existing_trial.get(trial.index)
-            if existing_trial is None:
-                raise ValueError(
-                    f"Trial {trial.index} is not attached to the experiment."
-                )
+    trial_index_to_existing_trial = {trial.index: trial for trial in existing_trials}
 
-            new_sqa_trial = encoder.trial_to_sqa(trial)
-            existing_trial.update(new_sqa_trial)
-            session.add(existing_trial)
+    updated_sqa_trials, new_sqa_data = [], []
+    for trial in trials:
+        existing_trial = trial_index_to_existing_trial.get(trial.index)
+        if existing_trial is None:
+            raise ValueError(f"Trial {trial.index} is not attached to the experiment.")
 
-            data, ts = experiment.lookup_data_for_trial(trial_index=trial.index)
-            if ts != -1:
-                sqa_data = encoder.data_to_sqa(
-                    data=data, trial_index=trial.index, timestamp=ts
-                )
-                sqa_data.experiment_id = experiment_id
-                session.add(sqa_data)
+        new_sqa_trial, _obj_to_sqa = encoder.trial_to_sqa(trial)
+        obj_to_sqa.extend(_obj_to_sqa)
+        existing_trial.update(new_sqa_trial)
+        updated_sqa_trials.append(existing_trial)
+
+        data, ts = experiment.lookup_data_for_trial(trial_index=trial.index)
+        if ts != -1:
+            sqa_data = encoder.data_to_sqa(
+                data=data, trial_index=trial.index, timestamp=ts
+            )
+            obj_to_sqa.append((data, sqa_data))
+            sqa_data.experiment_id = experiment_id
+            new_sqa_data.append(sqa_data)
+
+    with session_scope() as session:
+        session.add_all(updated_sqa_trials)
+        session.add_all(new_sqa_data)
+        session.flush()
+
+    _set_db_ids(obj_to_sqa=obj_to_sqa)
 
 
 def update_generation_strategy(
@@ -269,20 +316,30 @@ def _update_generation_strategy(
     """Update generation strategy's current step and attach generator runs."""
     gs_sqa_class = encoder.config.class_to_sqa_class[GenerationStrategy]
 
-    gs_id = generation_strategy._db_id
+    gs_id = generation_strategy.db_id
     if gs_id is None:
         raise ValueError("GenerationStrategy must be saved before being updated.")
 
+    obj_to_sqa = []
     with session_scope() as session:
         experiment_id = _get_experiment_id(
             experiment=generation_strategy.experiment, encoder=encoder, session=session
         )
-        gs_sqa = session.query(gs_sqa_class).get(gs_id)
-        gs_sqa.curr_index = generation_strategy._curr.index  # pyre-fixme
-        gs_sqa.experiment_id = experiment_id  # pyre-ignore
+        session.query(gs_sqa_class).filter_by(id=gs_id).update(
+            {
+                "curr_index": generation_strategy._curr.index,
+                "experiment_id": experiment_id,
+            }
+        )
 
-        session.add(gs_sqa)
-        for generator_run in generator_runs:
-            gr_sqa = encoder.generator_run_to_sqa(generator_run=generator_run)
-            gr_sqa.generation_strategy_id = gs_id
-            session.add(gr_sqa)
+    generator_runs_sqa = []
+    for generator_run in generator_runs:
+        gr_sqa, _obj_to_sqa = encoder.generator_run_to_sqa(generator_run=generator_run)
+        obj_to_sqa.extend(_obj_to_sqa)
+        gr_sqa.generation_strategy_id = gs_id
+        generator_runs_sqa.append(gr_sqa)
+
+    with session_scope() as session:
+        session.add_all(generator_runs_sqa)
+
+    _set_db_ids(obj_to_sqa=obj_to_sqa)
